@@ -48,6 +48,23 @@ def main():
     global config
     global RecordWindowGraph
    
+   
+   
+###############Usefull Time operations ###################################
+##    t_tuple=time.localtime()
+##    print t_touple
+##    t_tuple_formated=strftime("%H:%M:%S", t_tuple)
+##    print t_tuple_formated
+##    t_sec=time.mktime(t_tuple)
+##    print t_sec
+##    t_sec=t_sec+3600+600 #add 1 hour + 5 minute
+##    t_back_to_tuple=time.localtime(t_sec)
+##    print t_back_to_tuple
+###############T ime operations ###################################
+   
+   
+   
+   
     try:
         if(sys.argv[1]=="debug"): 
             print "Enable Debug mode"
@@ -131,8 +148,9 @@ def EditUserName():
 def TimerLoop(): #(interval: sampling*sample_smoothing*value_smoothing)
     global RecordWindowGraph    
 #    Show_passed_time("TimerLoop start")
-    r=GetSensorData() 
+    r=GetSensorData()     
     if(r==1): #new data got added to array
+#        print "Got SensorData"
         
         ProcessData()      
      
@@ -163,55 +181,6 @@ def TimerLoop(): #(interval: sampling*sample_smoothing*value_smoothing)
 
 
 
-def ProcessAlarm():
-    #add note to array for graph
-    if(data.arrDataIndex==0 and data.AlarmIsSet==True): #do only on first time and if alarm is set
-#        print "first loop run",  data.arrData[0][0]
-        t=string.split(data.arrData[0][0],  ":")
-        now=int(t[0])*3600+int(t[1])*60
-        al=int(data.AlarmHour)*3600+int(data.AlarmMinute)*60
-        alarmdiff=al-now
-        if(alarmdiff<0):  #set to tomorrow if time already is elapsed today
-            alarmdiff=alarmdiff+86400
-        
-        i=alarmdiff/10
-        
-        if(i<data.arrDataLen): 
-            data.arrData[5][i]="Alarm Time Window End" #Last oportunity for alarm
-#            print "Set Alarm Time Window End:",  i
-#            if(i-data.AlarmTimeWindow*6>0):
-            i=max(i-6*data.AlarmTimeWindow, 0)
-            data.arrData[5][i]="Alarm Time Window Begin" #First oportunity for alarm
-#            print "Set Alarm Time Window Begin:",  i
-        else:
-            print "EventSetAlarm is out of range"
-            
-#        print "Set Alarm time (index) to:",  i-data.AlarmTimeWindow*6,  "-",  i,  data.AlarmTimeWindow
-  
-    i=data.arrDataIndex-data.derivation            
-    if(i>1): peak=data.arrData[3][i-1]
-    else: peak=0
-#    print "Peak:",  peak,  data.trigger
-    if(peak>data.trigger): #Movement, check if time for alarm        
-        Now=int(strftime("%H", time.localtime()))*60+int(strftime("%M", time.localtime()))
-        Al=int(data.AlarmHour)*60+int(data.AlarmMinute)
-#        print "Now:", Now,  "Alarm:", Al,  "AlarmTimeWindow:", data.AlarmTimeWindow, "AlarmIsSet:", data.AlarmIsSet, "AlarmIsActive:",  data.AlarmIsActive
-        if(data.AlarmIsSet==True and data.AlarmIsActive==False and  Now>(Al-data.AlarmTimeWindow) and Now<=Al): #set Alarm off
-            print "************ ALARM ALARM *********************"
-            data.AlarmIsActive=True
-#            print "Mark alarm in array on index:",  data.arrDataIndex-1
-            data.arrData[5][data.arrDataIndex-1]="Alarm"      
-#            print "Add Alarm to array on index:",  data.arrDataIndex-1
-            data.AlarmHour=int(strftime("%H", time.localtime())) #set new alarm to go off now
-            data.AlarmMinute=int(strftime("%M", time.localtime()))
-#            if(data.demo==0): # we are on a N900
-            DeleteAlarm() #delete old alarm if existing
-            print "* Set new Alarm to current time"
-            SetAlarm(data.AlarmHour,  data.AlarmMinute) #set alarm to go off now
-#            else: 
-#                print "Can not set alarm off, Maemo interface not available"
-            return 1
-    else: return 0
 
 
 ###########################################################################
@@ -238,27 +207,42 @@ def InitStartMeasurement():
         data.interval=10 #Fast mode for testing
         data.Xscale=0 #set to max zoom level
     
-    data.run=1 #change to delayed start
+#    data.run=1 #change to delayed start
 
 
-    app.timer_Delay = QtCore.QTimer()
-    QtCore.QObject.connect(app.timer_Delay, QtCore.SIGNAL("timeout()"), StartDelayTimerLoop)     
-    print "QuickMode:",  data.QuickMode
-    if(data.QuickMode==1 or data.DelayStartTime==0): #quick mode
-        data.DelayStart=0
-        app.timer_Delay.start(1) #milliseconds  (make it very quick)
-    else:
-        data.DelayStart=data.DelayStartTime
-        app.timer_Delay.start(1000) #milliseconds         
+#    app.timer_Delay = QtCore.QTimer()
+#    QtCore.QObject.connect(app.timer_Delay, QtCore.SIGNAL("timeout()"), StartDelayTimerLoop)     
+#    print "QuickMode:",  data.QuickMode
+#    if(data.QuickMode==1 or data.DelayStartTime==0): #quick mode
+#        data.DelayStart=0
+#        app.timer_Delay.start(1) #milliseconds  (make it very quick)
+#    else:
+#        data.DelayStart=data.DelayStartTime
+#        app.timer_Delay.start(1000) #milliseconds         
         
     #Set Start times
 #    print "Set StartTime:",  data.StartTime,  data.StartTimeSec
+
+    data.run=2 #change to recording
+    app.timer_GetData = QtCore.QTimer()
+    QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)     
+
     data.StartTime=time.localtime()
     data.StartTimeSec=int(time.mktime(data.StartTime))
    
+#        if(data.demo==0): #we are on a N900
+    app.timer_GetData.start(data.interval)     
+#        else: #faster in demo mode
+#            app.timer_GetData.start(data.interval/10) 
+    
+    StartLogfile(data.interval)
+    if(data.AlarmIsSet==True): InitAlarm()
+    
+#    TimerLoop() #first run
+   
     data.ChangesInGraph=1 #Make sure it only gets refreshed once    
     RecordWindowGraph.update() #show RecordWindowGraph        
-    RecordWindow.UpdateScreen()     #needed?
+    RecordWindow.UpdateScreen()
     
     
         
@@ -275,27 +259,27 @@ def InitStartMeasurement():
 
     
     
-def StartDelayTimerLoop():
-#    print "StartDelayTimerLoop"
-    data.DelayStart=data.DelayStart-1
-    if(data.DelayStart<=0):  #delay over
-        app.timer_Delay.stop()
-        
-        data.run=2 #change to recording
-        
-        app.timer_GetData = QtCore.QTimer()
-        QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)     
-        
-#        if(data.demo==0): #we are on a N900
-        app.timer_GetData.start(data.interval) 
-#        else: #faster in demo mode
-#            app.timer_GetData.start(data.interval/10) 
-        
-        StartLogfile(data.interval)
-        RecordWindow.UpdateScreenStart() 
-        
-    else:
-        RecordWindow.DelayStart()
+#def StartDelayTimerLoop():
+##    print "StartDelayTimerLoop"
+#    data.DelayStart=data.DelayStart-1
+#    if(data.DelayStart<=0):  #delay over
+#        app.timer_Delay.stop()
+#        
+#        data.run=2 #change to recording
+#        
+#        app.timer_GetData = QtCore.QTimer()
+#        QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)     
+#        
+##        if(data.demo==0): #we are on a N900
+#        app.timer_GetData.start(data.interval) 
+##        else: #faster in demo mode
+##            app.timer_GetData.start(data.interval/10) 
+#        
+#        StartLogfile(data.interval)
+#        RecordWindow.UpdateScreenStart() 
+#        
+#    else:
+#        RecordWindow.DelayStart()
     
 
 
@@ -303,9 +287,9 @@ def StartDelayTimerLoop():
 
 def StopMeasurement():
     global app
-    if(data.run==1): #in delayed start
-        app.timer_Delay.stop()
-    elif(data.run==2): #in recording
+#    if(data.run==1): #in delayed start
+#        app.timer_Delay.stop()
+    if(data.run==2): #in recording
         app.timer_GetData.stop()
         StopLogfile() 
    
@@ -437,7 +421,8 @@ class frmStartWindow(QMainWindow):
         RecordWindow.show()
         RecordWindowGraph = RecordWindowCanvas(RecordWindow)
         InitStartMeasurement()
-        RecordWindow.UpdateScreenDelayStart()
+#        RecordWindow.UpdateScreenDelayStart()
+        RecordWindow.UpdateScreenStart()
         RecordWindowGraph.show()
         
         
@@ -563,34 +548,37 @@ class frmRecordWindow(QMainWindow):
             self.ui.bLowerTrigger.setIcon(QIcon(data.app_path+"img/"+"go-down.png"))
             self.ui.bEditNote.setIcon(QIcon(data.app_path+"img/"+"kwrite.png"))
             
-
-    def UpdateScreenDelayStart(self):
-        self.ui.lblStarttime.setText("(Delayed "+str(data.DelayStart)+" sec)")
-#        t= t=strftime("%d. %b %Y %H:%M:%S", data.StartTime)
-#        self.ui.lblStarttime.setText("")
-        self.ui.lblSamples_Taken.setText("")
-        self.ui.lblElapsedTime.setText("")
-        self.ui.lblNote.setText("")
-#        self.ui.lblLogfile.setText("")
-#        self.ui.lblYscale.setText(str(data.Yscale))
-#        self.ui.lblTrigger.setText(str(data.trigger))
-        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
-        self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec2.png"))
-        self.ui.bStop.setText("Stop")
-
-        if(data.AlarmIsSet==True): #alarm active
-            m=str(data.AlarmMinute)
-            if(len(m)==1): m="0"+m
-            self.ui.lblAlarmTime.setText(str(data.AlarmHour)+":"+m+" or up to "+str(data.AlarmTimeWindow)+" minutes before that")
-        else: #only recording, no alarm
-            self.ui.lblAlarmTime.setText("(Not set)")
             
-        self.UpdateScreen()
+            
+            
+
+#    def UpdateScreenDelayStart(self):
+#        self.ui.lblStarttime.setText("(Delayed "+str(data.DelayStart)+" sec)")
+##        t= t=strftime("%d. %b %Y %H:%M:%S", data.StartTime)
+##        self.ui.lblStarttime.setText("")
+#        self.ui.lblSamples_Taken.setText("")
+#        self.ui.lblElapsedTime.setText("")
+#        self.ui.lblNote.setText("")
+##        self.ui.lblLogfile.setText("")
+##        self.ui.lblYscale.setText(str(data.Yscale))
+##        self.ui.lblTrigger.setText(str(data.trigger))
+#        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
+#        self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec2.png"))
+#        self.ui.bStop.setText("Stop")
+#
+#        if(data.AlarmIsSet==True): #alarm active
+#            m=str(data.AlarmMinute)
+#            if(len(m)==1): m="0"+m
+#            self.ui.lblAlarmTime.setText(str(data.AlarmHour)+":"+m+" or up to "+str(data.AlarmTimeWindow)+" minutes before that")
+#        else: #only recording, no alarm
+#            self.ui.lblAlarmTime.setText("(Not set)")
+#            
+#        self.UpdateScreen()
         
         
         
-    def DelayStart(self):
-        self.ui.lblStarttime.setText("(Delayed "+str(data.DelayStart)+" sec)")
+#    def DelayStart(self):
+#        self.ui.lblStarttime.setText("(Delayed "+str(data.DelayStart)+" sec)")
         
 
 
@@ -604,27 +592,33 @@ class frmRecordWindow(QMainWindow):
 #        self.ui.lblNote.setText("")
 #        self.ui.lblYscale.setText(str(data.Yscale))
 #        self.ui.lblTrigger.setText(str(data.trigger))
-#        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
-#        self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec2.png"))
+        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
+        self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec2.png"))
 #        self.ui.bStop.setText("Stop recording")
+
+        if(data.AlarmIsSet==True): #alarm active
+            m=str(data.AlarmMinute)
+            if(len(m)==1): m="0"+m
+            self.ui.lblAlarmTime.setText(str(data.AlarmHour)+":"+m+" or up to "+str(data.AlarmTimeWindow)+" minutes before that")
+        else: #Do only recording, no alarm
+            self.ui.lblAlarmTime.setText("(No Alarm set)")
                         
         self.UpdateScreen()
         
         
         
     def UpdateScreen(self):
-        if(data.demo==0):
-            self.ui.lblSamples_Taken.setText(str(data.values_total))
-        else:
-            self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Demo Mode)")
+#        if(data.demo==0):
+#            self.ui.lblSamples_Taken.setText(str(data.values_total))
+#        else:
+#            self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Demo Mode)")
 
 #        print "UpdateScreen",  data.run
         if(data.run==2): #recording
             t=time.mktime(time.localtime())
             time_difference=t-data.StartTimeSec
-            t=strftime("%H:%M:%S", time.localtime(time_difference))
-            self.ui.lblElapsedTime.setText(t)
-#        self.ui.lblTrigger.setText(str(data.trigger))
+            d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
+            self.ui.lblElapsedTime.setText(d + " ("+str(data.values_total)+" records)")
         
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
@@ -641,7 +635,7 @@ class frmRecordWindow(QMainWindow):
         
     def UpdateScreenStop(self):
 #        self.ui.lblStarttime.setText("(Stopped)")
-        self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Stopped)")
+#        self.ui.lblSamples_Taken.setText(str(data.values_total)+" (Stopped)")
         self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec.png"))
         self.ui.bStop.setText("Start")
         
@@ -652,11 +646,12 @@ class frmRecordWindow(QMainWindow):
         global app
         if(data.run==0): #not running
             InitStartMeasurement()
-            self.UpdateScreenDelayStart()
-        elif(data.run==1): # in delayed start
-            StopMeasurement()
-            self.UpdateScreenStop()
-            data.test=0 # reset test mode if was active
+#            self.UpdateScreenDelayStart()
+            self.UpdateScreenStart()
+#        elif(data.run==1): # in delayed start
+#            StopMeasurement()
+#            self.UpdateScreenStop()
+#            data.test=0 # reset test mode if was active
         else: #running
             StopMeasurement()
             self.AskKeepRecord()  
@@ -669,14 +664,17 @@ class frmRecordWindow(QMainWindow):
 #        self.ui.bZoomOut.setEnabled(True)
 #        if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
 #        else: self.ui.bZoomIn.setEnabled(True)
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
         self.update()
         self.UpdateScreen()
+        
 
     def ZoomOut(self):
-        r=Zoom(-1)
+        Zoom(-1)
 #        self.ui.bZoomIn.setEnabled(True)
 #        if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
 #        else: self.ui.bZoomOut.setEnabled(True)
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
         self.update()
         self.UpdateScreen()
 
@@ -1087,7 +1085,6 @@ class frmConfigWindow(QMainWindow):
             data.OfflineMode="False"
         config.set('main', 'OfflineMode', str(data.OfflineMode))   
         config.set('main', 'user', str(data.user))      
-#        data.DelayStartTime=int(self.ui.SliderStartDelay.value())
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))      
         
         ConfigWindow.close()
@@ -1100,8 +1097,11 @@ class frmConfigWindow(QMainWindow):
         
         
     def SliderMoved(self):
-        data.DelayStartTime=self.ui.SlrDelayStart.value()
+        x=self.ui.SlrDelayStart.value()
+        data.DelayStartTime=x
         self.ui.lblDelayStart.setText(str(data.DelayStartTime)+" sec")
+#        data.DropIndexes=(data.sampling*data.value_smoothing)/1000
+#        print data.DropIndexes
 
 
 
@@ -1200,12 +1200,11 @@ class frmAlarmTimeWindow(QMainWindow):
         print "Alarm time:",  data.AlarmHour, ":",  data.AlarmMinute
         self.ui.lstAlarmHour.setCurrentRow(int(data.AlarmHour))
         self.ui.lstAlarmMinute.setCurrentRow(int(data.AlarmMinute)/5)
-        s="The Alarm will go off on the set time or maximum "+str(data.AlarmTimeWindow)+" minutes earlier, depending on your movements."
+        self.ui.lstAlarmTimeWindow.setCurrentRow(int(data.AlarmTimeWindow)/5-1)
+#        s="The Alarm will go off on the set time or maximum "+str(data.AlarmTimeWindow)+" minutes earlier, depending on your movements."
+        s="The Alarm will then go off sometimes during the time window (as soon as you move more), but latest at the set alarm time."
         self.ui.lblNote.setText(s)
 
-        
-        
-
     def SetAlarm(self):
         global RecordWindowGraph
         print "Set Alarm"
@@ -1217,8 +1216,10 @@ class frmAlarmTimeWindow(QMainWindow):
         try:
             data.AlarmHour=int(self.ui.lstAlarmHour.currentItem().text())
             data.AlarmMinute=int(self.ui.lstAlarmMinute.currentItem().text())
+            data.AlarmTimeWindow=int(self.ui.lstAlarmTimeWindow.currentItem().text())
             config.set('main', 'AlarmHour', str(data.AlarmHour))  
             config.set('main', 'AlarmMinute', str(data.AlarmMinute))  
+            config.set('main', 'AlarmTimeWindow', str(data.AlarmTimeWindow))  
         except: #If nothing selected (workaround)
 #            data.AlarmHour=7
 #            data.AlarmMinute=0
@@ -1226,8 +1227,6 @@ class frmAlarmTimeWindow(QMainWindow):
 
         
         
-        
-        
         Now=int(strftime("%H", time.localtime()))*3600+int(strftime("%M", time.localtime()))*60 #nows h+m in secs
         alarm=int(data.AlarmHour)*3600+int(data.AlarmMinute)*60 #alarm h+m in secs
         alarmdiff=alarm-Now #difference
@@ -1250,7 +1249,8 @@ class frmAlarmTimeWindow(QMainWindow):
         RecordWindow.show()
         AlarmTimeWindow.hide()
 #        InitStartMeasurement()
-        RecordWindow.UpdateScreenDelayStart()
+#        RecordWindow.UpdateScreenDelayStart()
+        RecordWindow.UpdateScreenStart()
         RecordWindowGraph.show()
 
 
@@ -1271,7 +1271,7 @@ class frmAlarmTimeWindow(QMainWindow):
 class RecordWindowCanvas(QtGui.QWidget):
     def __init__(self, parent):
         QMainWindow.__init__(self, parent)    
-        self.setGeometry(9, 185, 782, data.Ysize+55)
+        self.setGeometry(9, 180, 782, data.Ysize+55)
     
     def paintEvent(self, event):
         showGraph(self,  QtGui)
