@@ -175,7 +175,7 @@ def OpenLogFile():
 #            t=string.split(t, ":")
             data.AlarmTimeWindow=int(t)
 
-            data.DelayStartTime=0
+            data.DelayStartTime=0 #needed?
             data.AlarmTimeSec=time.mktime(time.strptime(data.AlarmDate+" "+str(data.AlarmHour)+":"+str(data.AlarmMinute), "%d-%m-%Y %H:%M"))
             
             print "Header Alarm time:",  data.AlarmHour,  ":",  data.AlarmMinute,  "AlarmTimeWindow:",  data.AlarmTimeWindow
@@ -291,6 +291,7 @@ def LoadConfig():
         data.DelayStartTime = config.getint('main', 'DelayStartTime')
         data.AlarmHour = config.getint('main', 'AlarmHour')
         data.AlarmMinute = config.getint('main', 'AlarmMinute')
+        data.AlarmTimeWindow = config.getint('main', 'AlarmTimeWindow')
         print "Configuration loaded ("+data.ConfigFile+")"
 #    else:
     except: #use default config
@@ -313,6 +314,7 @@ def LoadConfig():
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))    
         config.set('main', 'AlarmHour', str(data.AlarmHour))    
         config.set('main', 'AlarmMinute', str(data.AlarmMinute))    
+        config.set('main', 'AlarmTimeWindow', str(data.AlarmTimeWindow))    
 
     return config
 
