@@ -99,10 +99,18 @@ def ProcessData():
 #        print i,  data.arrData[0][i] ,  data.arrData[1][i],  data.arrData[2][i]  
 
     lastmove=0 
-    for i in range(0, data.arrDataIndex-data.derivation):        
-        Xder=data.arrData[1][i+data.derivation] - data.arrData[1][i] #X  in 5 sec - X now
-        Yder=data.arrData[2][i+data.derivation] - data.arrData[2][i]  #Y  in 5 sec - Y now
-        XYder=abs(Xder)+abs(Yder) #summ of both absolute derivations
+    for i in range(0, data.arrDataIndex-data.derivation):     
+        t=i*(data.interval*data.value_smoothing)/1000
+#        print t,  data.DelayStartTime,  data.QuickMode
+        if(data.QuickMode==1 or t>data.DelayStartTime):
+            Xder=data.arrData[1][i+data.derivation] - data.arrData[1][i] #X  in 5 sec - X now
+            Yder=data.arrData[2][i+data.derivation] - data.arrData[2][i]  #Y  in 5 sec - Y now
+            XYder=abs(Xder)+abs(Yder) #summ of both absolute derivations
+        else: #During delayed phase, do not use data
+#            print "Drop derivation, still in Start delay"
+            Xder=0
+            Yder=0
+            XYder=0
         data.arrData[3][i]=min(XYder*data.Yscale,  data.Ysize-17) #cut off if higer than graph border
 
     Show_passed_time("ProcessData End")
@@ -146,10 +154,12 @@ def showGraph(self,  QtGui):
             h0=int(t[0])
             m0=int(t[1])
         except:
-            Now=int(strftime("%H", time.localtime()))*3600+int(strftime("%M", time.localtime()))*60 #nows h+m in secs
-            t=float(Now+data.DelayStartTime)
-            h0=int(math.floor(t/3600))
-            m0=int((t-h0*3600)/60)
+#            Now=int(strftime("%H", time.localtime()))*3600+int(strftime("%M", time.localtime()))*60 #nows h+m in secs
+#            h0=int(math.floor(Now/3600))
+#            m0=int((Now-h0*3600)/60)
+
+            h0=int(time.strftime("%H", time.localtime()))
+            m0=int(time.strftime("%M", time.localtime()))
             
 #            print "Graph will start at",  Now,  t            
 #        print "Start time of graph:",  h0,  ":",  m0
@@ -163,6 +173,8 @@ def showGraph(self,  QtGui):
         
         Show_passed_time("showGraph Preparations done")
         
+        
+        # ##############################################
         #DRAW main scaling lines + text        
         paint.setPen(QtGui.QColor("white"))
         if(data.test==0):
@@ -184,13 +196,6 @@ def showGraph(self,  QtGui):
             paint.drawText(200, data.Ysize+20, "Test Mode")
 
 
-        #DRAW trigger line
-        y=(data.Ysize-(data.trigger*data.Yscale))-2
-        paint.drawLine(1, y-15, 781, y-15)  #trigger line
-        paint.drawText(760, y-17, str(data.trigger)) #trigger level
-        paint.drawText(5, 15, str(data.Yscale)) #Y scale
-
-
         #DRAW scroll bar 
         start=data.GraphStart
         end=start+775
@@ -210,6 +215,7 @@ def showGraph(self,  QtGui):
 
 
 
+        # ##############################################
         #DRAW graph
         end=min(data.arrDataIndex,  data.GraphStart+779*Xscale)
         end=end-data.derivation
@@ -278,16 +284,20 @@ def showGraph(self,  QtGui):
         
            
 
+        # ##############################################
         #ALARM VISUALISATION
         if(data.AlarmHour>-1 and  data.AlarmMinute>-1 and data.QuickMode==0): #we are recording normaly and an alarm is set, or we loaded a record with set alarm
-            timediff=(data.AlarmTimeSec - (data.StartTimeSec+data.DelayStartTime)) #diff until alarm
+#            timediff=(data.AlarmTimeSec - (data.StartTimeSec+data.DelayStartTime)) #diff until alarm
+            timediff=(data.AlarmTimeSec - data.StartTimeSec) #diff until alarm
             t=(data.interval*data.value_smoothing)/1000
 #            print data.interval,  data.value_smoothing,  t,  data.StartTimeSec
-            IndexAlarm=timediff/t
-            timediff2=(data.AlarmTimeSec - (data.StartTimeSec+data.DelayStartTime)) - data.AlarmTimeWindow*60 #diff until alarm - AlarmTimeWindow
-            IndexAlarm2=timediff2/t
+            IndexAlarm=int(timediff/t)
+#            timediff2=(data.AlarmTimeSec - (data.StartTimeSec+data.DelayStartTime)) - data.AlarmTimeWindow*60 #diff until alarm - AlarmTimeWindow
+            timediff2=(data.AlarmTimeSec - data.StartTimeSec) - data.AlarmTimeWindow*60 #diff until alarm - AlarmTimeWindow
+            IndexAlarm2=int(timediff2/t)
             
 #            print "First index will be at (absolute secs)", data.StartTimeSec+data.DelayStartTime
+#            print "First index will be at (absolute secs)", data.StartTimeSec
 #            print "Alarm is in seconds after recording start:",  timediff,  ", AlarmTimeWindow:",  timediff2
 #            print "Index for Alarm will be at",  IndexAlarm,  "AlarmTimeWindow:",  IndexAlarm2 #divided by 10 (1 index = 10secs
 #            print "Draw Alarm data:",  data.AlarmHour,":",   data.AlarmMinute,  data.AlarmIsSet,  data.AlarmTimeWindow,  data.AlarmIsActive
@@ -305,10 +315,11 @@ def showGraph(self,  QtGui):
                 paint.drawRect(x1-1,  4,  2,  10) 
         
             #draw AlarmTimeWindow
-            x0=max(x0, data.GraphStart)
-            x0=min(x0, (data.GraphStart+755*Xscale))            
-            x1=max(x1, x0)
-            x1=min(x1, (data.GraphStart+755*Xscale))
+#            print "AlarmTimeWindow (uncorrected):",  x0,  "-",  x1
+#            x0=max(x0, data.GraphStart)
+#            x0=min(x0, (data.GraphStart+755*Xscale))            
+#            x1=max(x1, x0)
+#            x1=min(x1, (data.GraphStart+755*Xscale))
 #            print "AlarmTimeWindow:",  x0,  "-",  x1
             if((x1-x0)>0): paint.drawRect(x0,  8,  x1-x0,  2) #Time Window 
             
@@ -322,12 +333,26 @@ def showGraph(self,  QtGui):
 #                    print "Found Alarm entry on index:",  x
                     x=(i-data.GraphStart)/Xscale              
                     paint.drawEllipse(x-5, 15, 10, 10)             
-        
-        
-
-
            
            
+           
+           
+           
+           
+           
+        # ##############################################
+       #DRAW trigger line
+        paint.setPen(QtGui.QColor("white"))
+#        paint.setBrush(QtGui.QColor("white"))
+        y=(data.Ysize-(data.trigger*data.Yscale))-2
+        paint.drawLine(1, y-15, 781, y-15)  #trigger line
+        paint.drawText(760, y-17, str(data.trigger)) #trigger level
+        paint.drawText(5, 15, str(data.Yscale)) #Y scale
+           
+           
+           
+           
+        # ##############################################
         #beep in test mode
         if(peak>data.trigger): #if last value is over peak
             if(data.QuickMode==1 and (end-data.derivation)>data.last_beep): #quick mode for testing but only once pr move
@@ -435,24 +460,58 @@ def DeleteAlarm():
 
 
 
+def InitAlarm():
+#add note to array for graph
+#    if(data.arrDataIndex==0 and data.AlarmIsSet==True): #do only on first time and if alarm is set
+#        print "first loop run",  data.arrData[0][0]
+#    t=string.split(data.arrData[0][0],  ":")
+    now=int(strftime("%H", data.StartTime))*3600+int(strftime("%M", data.StartTime))*60
+    al=int(data.AlarmHour)*3600+int(data.AlarmMinute)*60
+    alarmdiff=al-now
+    if(alarmdiff<0):  #set to tomorrow if time already is elapsed today
+        alarmdiff=alarmdiff+86400
+    
+    i=alarmdiff/10
+    
+    if(i<data.arrDataLen): 
+        data.arrData[5][i]="Alarm Time Window End" #Last oportunity for alarm
+#            print "Set Alarm Time Window End:",  i
+#            if(i-data.AlarmTimeWindow*6>0):
+        i=max(i-6*data.AlarmTimeWindow, 0)
+        data.arrData[5][i]="Alarm Time Window Begin" #First oportunity for alarm
+#            print "Set Alarm Time Window Begin:",  i
+    else:
+        print "EventSetAlarm is out of range"
+        
+#        print "Set Alarm time (index) to:",  i-data.AlarmTimeWindow*6,  "-",  i,  data.AlarmTimeWindow
 
 
-#def getSecondsUntilAlarm(h, m):
-#    now=h*3600+m*60
-#    al=int(data.AlarmHour)*3600+int(data.AlarmMinute)*60
-#    alarmdiff=al-now
-#    if(alarmdiff<0):  #set to tomorrow if time already is elapsed today
-#        alarmdiff=alarmdiff+86400
-##        print "Alarm will be tomorrow"
-##    print "Now:", now,  "Alarm:", al,  "Difference:", alarmdiff
-#
-#    return alarmdiff
-#    
-    
-    
-    
-    
-    
+
+def ProcessAlarm():
+    i=data.arrDataIndex-data.derivation            
+    if(i>1): peak=data.arrData[3][i-1]
+    else: peak=0
+#    print "Peak:",  peak,  data.trigger
+    if(peak>data.trigger): #Movement, check if time for alarm        
+        Now=int(strftime("%H", time.localtime()))*60+int(strftime("%M", time.localtime()))
+        Al=int(data.AlarmHour)*60+int(data.AlarmMinute)
+#        print "Now:", Now,  "Alarm:", Al,  "AlarmTimeWindow:", data.AlarmTimeWindow, "AlarmIsSet:", data.AlarmIsSet, "AlarmIsActive:",  data.AlarmIsActive
+        if(data.AlarmIsSet==True and data.AlarmIsActive==False and  Now>(Al-data.AlarmTimeWindow) and Now<=Al): #set Alarm off
+            print "************ ALARM ALARM *********************"
+            data.AlarmIsActive=True
+#            print "Mark alarm in array on index:",  data.arrDataIndex-1
+            data.arrData[5][data.arrDataIndex-1]="Alarm"      
+#            print "Add Alarm to array on index:",  data.arrDataIndex-1
+            h=int(strftime("%H", time.localtime())) #set new alarm to go off now
+            m=int(strftime("%M", time.localtime()))
+#            if(data.demo==0): # we are on a N900
+            DeleteAlarm() #delete old alarm if existing
+            print "* Set new Alarm to current time"
+            SetAlarm(h,  m) #set alarm to go off now
+#            else: 
+#                print "Can not set alarm off, Maemo interface not available"
+            return 1
+    else: return 0
     
     
     
